@@ -1,24 +1,31 @@
 import sqlalchemy as sa
-from sqlalchemy_utils import table_name
 from .builder import VersionedBuilder
 
 
 class VersionedTableBuilder(VersionedBuilder):
-    @property
-    def table_name(self):
-        return self.option('table_name') % table_name(self.model)
+    def __init__(
+        self,
+        versioning_manager,
+        parent_table,
+        model=None,
+        remove_primary_keys=False
+    ):
+        self.manager = versioning_manager
+        self.parent_table = parent_table
+        self.model = model
+        self.remove_primary_keys = remove_primary_keys
 
     @property
-    def parent_columns(self):
-        """
-        Returns a list of parent table columns.
-        """
-        return self.model.__table__.c.values()
+    def table_name(self):
+        return self.option('table_name') % self.parent_table.name
 
     def build_reflected_columns(self):
         columns = []
+        excluded_column_names = self.option('exclude')
 
-        for column in self.parent_columns:
+        for column in self.parent_table.c:
+            if self.model and column.name in excluded_column_names:
+                continue
             # Make a copy of the column so that it does not point to wrong
             # table.
             column_copy = column.copy()
@@ -26,19 +33,13 @@ class VersionedTableBuilder(VersionedBuilder):
             column_copy.unique = False
             column_copy.autoincrement = False
             column_copy.nullable = True
-            if column_copy.primary_key:
+            if column_copy.name == 'revision':
+                column_copy.primary_key = True
+            if self.remove_primary_keys:
                 column_copy.primary_key = False
             columns.append(column_copy)
         return columns
 
-    def build_revision_column(self):
-        return sa.Column(
-            self.option('revision_column_name'),
-            sa.BigInteger,
-            primary_key=True,
-            autoincrement=True
-        )
-
     def build_operation_type_column(self):
         return sa.Column(
             self.option('operation_type_column_name'),
@@ -52,27 +53,15 @@ class VersionedTableBuilder(VersionedBuilder):
             sa.BigInteger,
         )
 
-    @property
-    def metadata(self):
-        for base in self.model.__bases__:
-            if hasattr(base, 'metadata'):
-                return base.metadata
-
-        raise Exception(
-            'Unable to find base class with appropriate metadata extension'
-        )
-
     def build_table(self, extends=None):
         items = []
         if extends is None:
             items.extend(self.build_reflected_columns())
-            items.append(self.build_revision_column())
             items.append(self.build_transaction_column())
             items.append(self.build_operation_type_column())
-
         return sa.schema.Table(
             extends.name if extends is not None else self.table_name,
-            self.metadata,
+            self.parent_table.metadata,
             *items,
             extend_existing=extends is not None
         )
